==> mythical-player-1.0.3.tgz: package/js/modules/myth-playlist/index.js <==
import { virtual } from 'haunted';
import { html, nothing } from 'lit-html';
import { isKeyEnterOrKeySpace, isEventClick } from 'a11y-key-conjurer';
import { classMap } from 'lit-html/directives/class-map.js';
import { MythCoverFallback } from '../myth-cover-fallback';
import { MythTrackText } from '../myth-track-text';
import { getCover } from '../../_lib/get-cover';
import { MythIcon } from '../myth-icon';
import { MythFileExtension } from '../myth-file-extension';
import {
  readable as formatTime,
  iso as formatTimeDuration
} from 'mystic-format-time';

export const MythPlaylist = virtual(
  ({ playlist, list = {}, indexSelected, isPlaying, handleAudio, listId }) => {
    const {
      showCovers = true,
      showTrackNumber = true,
      showIconIsPlaying = true,
      showFileExtension = true
    } = list;
    function handleButton(index) {
      return ev => {
        if (isEventClick(ev) || isKeyEnterOrKeySpace(ev)) {
          ev.preventDefault();
          handleAudio.setTrack({ index, fromControls: false });
        }
      };
    }
    return html`
      <div class="myth-playlist" id="${listId}">
        <ul class="myth-playlist__items">
          ${playlist.map((item, index) => {
            const isPlayingItem = indexSelected === index;
            const itemClasses = classMap({
              'myth-playlist__item': true,
              'is-playing': isPlayingItem
            });
            return html`
              <li class="${itemClasses}" data-playlist-item="${index}">
                <div
                  class="myth-playlist__item-button"
                  tabindex="0"
                  role="button"
                  @click="${handleButton(index)}"
                  @keydown="${handleButton(index)}"
                >
                  ${showCovers
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-playlist__item-image"
                        >
                          ${item.cover
                            ? html`<img
                                src="${getCover(item.cover)}"
                                alt=""
                                aria-hidden="true"
                              />`
                            : MythCoverFallback({ isInFileItem: true })}
                        </div>
                      `
                    : nothing}
                  ${showIconIsPlaying && isPlayingItem
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-playlist__item-playing-icon"
                        >
                          ${MythIcon({
                            icon: isPlaying ? 'play-arrow' : 'pause'
                          })}
                        </div>
                      `
                    : nothing}
                  ${showTrackNumber
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-item-text size-small"
                        >
                          ${item.trackNumber || index + 1}
                        </div>
                      `
                    : nothing}
                  <div class="myth-playlist__item-block">
                    ${MythTrackText({
                      title: item.title,
                      artist: item.artist,
                      album: item.album
                    })}
                  </div>
                  ${item.duration || showFileExtension
                    ? html`
                        <div class="myth-playlist__item-group is-last-right">
                          <time
                            class="myth-playlist__item-block myth-item-text size-small"
                            datetime="${formatTimeDuration(item.duration)}"
                          >
                            ${formatTime(item.duration)}
                          </time>
                          ${showFileExtension
                            ? html`
                                <div class="myth-playlist__item-block">
                                  ${MythFileExtension({ text: item.format })}
                                </div>
                              `
                            : nothing}
                        </div>
                      `
                    : nothing}
                </div>
              </li>
            `;
          })}
        </ul>
      </div>
    `;
  }
);

==> mythical-player-1.1.1.tgz: package/js/modules/myth-playlist/index.js <==
import { virtual } from 'haunted';
import { html, nothing } from 'lit-html';
import { isKeyEnterOrKeySpace, isEventClick } from 'a11y-key-conjurer';
import { classMap } from 'lit-html/directives/class-map.js';
import { MythCoverFallback } from '../myth-cover-fallback';
import { MythTrackText } from '../myth-track-text';
import { getCover } from '../../_lib/get-cover';
import { MythIcon } from '../myth-icon';
import { MythFileExtension } from '../myth-file-extension';
import {
  readable as formatTime,
  iso as formatTimeDuration
} from 'mystic-format-time';

export const MythPlaylist = virtual(
  ({ playlist, list = {}, indexSelected, isPlaying, handleAudio, listId }) => {
    const {
      showCovers = true,
      showTrackNumber = true,
      showIconIsPlaying = true,
      showFileExtension = true
    } = list;
    function handleButton(index) {
      return ev => {
        if (isEventClick(ev) || isKeyEnterOrKeySpace(ev)) {
          ev.preventDefault();
          handleAudio.setTrack({ index, fromControls: false });
        }
      };
    }
    return html`
      <div class="myth-playlist" id="${listId}">
        <ul class="myth-playlist__items">
          ${playlist.map((item, index) => {
            const isPlayingItem = indexSelected === index;
            const itemClasses = classMap({
              'myth-playlist__item': true,
              'is-playing': isPlayingItem
            });
            return html`
              <li class="${itemClasses}" data-playlist-item="${index}">
                <div
                  class="myth-playlist__item-button"
                  tabindex="0"
                  role="button"
                  @click="${handleButton(index)}"
                  @keydown="${handleButton(index)}"
                >
                  ${showCovers
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-playlist__item-image"
                        >
                          ${item.cover
                            ? html`<img
                                src="${getCover(item.cover)}"
                                alt=""
                                aria-hidden="true"
                              />`
                            : MythCoverFallback({ isInFileItem: true })}
                        </div>
                      `
                    : nothing}
                  ${showIconIsPlaying && isPlayingItem
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-playlist__item-playing-icon"
                        >
                          ${MythIcon({
                            icon: isPlaying ? 'play-arrow' : 'pause',
                            extraClasses:
                              'myth-playlist__item-playing-icon-inner'
                          })}
                        </div>
                      `
                    : nothing}
                  ${showTrackNumber
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-item-text size-small"
                        >
                          ${item.trackNumber || index + 1}
                        </div>
                      `
                    : nothing}
                  <div class="myth-playlist__item-block">
                    ${MythTrackText({
                      title: item.title,
                      artist: item.artist,
                      album: item.album
                    })}
                  </div>
                  ${item.duration || showFileExtension
                    ? html`
                        <div class="myth-playlist__item-group is-last-right">
                          <time
                            class="myth-playlist__item-block myth-item-text size-small"
                            datetime="${formatTimeDuration(item.duration)}"
                          >
                            ${formatTime(item.duration)}
                          </time>
                          ${showFileExtension
                            ? html`
                                <div class="myth-playlist__item-block">
                                  ${MythFileExtension({ text: item.format })}
                                </div>
                              `
                            : nothing}
                        </div>
                      `
                    : nothing}
                </div>
              </li>
            `;
          })}
        </ul>
      </div>
    `;
  }
);
